#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-5q27ruTR56ZmxgN8S35du
key:                  isomorphism-class-0.1.1-5q27ruTR56ZmxgN8S35du
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  2ba83646629b3f1c5d12764f8b478d44
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-5q27ruTR56ZmxgN8S35du
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5 text-2.0.2
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

